@@ -3,9 +3,7 @@ Command line reference manager with a single source of truth: the .bib file.
 Inspired by beets.
 """
 
-import os
 import pkg_resources
-import sys
 
 import click
 import click_constraints
@@ -18,20 +16,17 @@ from . import cite
 from . import internals
 from . import query
 
-PATH_OPTION = click.Path(writable=True, readable=True, dir_okay=False)
 FILE_OPTIONS = internals.combine_decorators(
     [
         click.option(
             "--file",
             help="Path to file to link to this entry.",
             type=click.Path(exists=True, readable=True, dir_okay=False),
-            autocompletion=internals.complete_path,
         ),
         click.option(
             "--destination",
             help="A folder to put the file in.",
             type=click.Path(exists=True, readable=True, dir_okay=True, file_okay=False),
-            autocompletion=internals.complete_path,
         ),
         click.option(
             "--no-copy",
@@ -49,7 +44,7 @@ FILE_OPTIONS = internals.combine_decorators(
 SEARCH_TERMS_OPTION = click.argument(
     "search_term",
     nargs=-1,
-    autocompletion=internals.complete_key,
+    shell_complete=internals.complete_key,
 )
 
 
@@ -63,13 +58,18 @@ SEARCH_TERMS_OPTION = click.argument(
 A path to a .bib file. Overrides the BIBO_DATABASE environment variable.
 """,
     required=True,
-    type=PATH_OPTION,
-    autocompletion=internals.complete_path,
+    type=click.Path(
+        file_okay=True,
+        dir_okay=False,
+        writable=True,
+        readable=True,
+        resolve_path=True,
+    ),
 )
 @click.pass_context
 def cli(ctx, database):
     ctx.ensure_object(dict)
-    ctx.obj["database"] = os.path.abspath(database)
+    ctx.obj["database"] = database
     ctx.obj["data"] = internals.load_database(database)
 
 
@@ -239,7 +239,7 @@ def add(ctx, destination, doi, no_copy, **kwargs):
 
 
 @cli.command(short_help="Remove an entry or a field.")
-@click.argument("key", autocompletion=internals.complete_key)
+@click.argument("key", shell_complete=internals.complete_key)
 @click.argument("field", nargs=-1)
 @click.pass_context
 def remove(ctx, key, field):
@@ -267,7 +267,7 @@ def remove(ctx, key, field):
 
 
 @cli.command(short_help="Edit an entry.")
-@click.argument("key", autocompletion=internals.complete_key)
+@click.argument("key", shell_complete=internals.complete_key)
 @click.argument("field_value", nargs=-1)
 @FILE_OPTIONS
 @click.pass_context
