@@ -2,7 +2,6 @@
 
 import collections
 import collections.abc
-import glob
 import itertools
 import os
 import re
@@ -118,6 +117,8 @@ def set_file(data, entry, file_, destination=None, no_copy=False):
     basename = string_to_basename(entry["key"])
     path = os.path.join(destination, basename + file_extension)
     entry["fields"]["file"] = path
+    if os.path.exists(path):
+        raise click.ClickException("{} already exists".format(path))
     click.echo("Copying {} to {}".format(file_, path))
     shutil.copy(file_, path)
 
@@ -133,23 +134,17 @@ def editor(*args, **kwargs):
     return result
 
 
-def get_database(args):
-    for arg_a, arg_b in zip(args, args[1:]):
-        if arg_a == "--database":
-            return arg_b
-
-
-def complete_key(ctx, args, incomplete):
+def complete_key(ctx, param, incomplete):
     """
     Autocompletion for keys.
     """
-    database = get_database(args) or os.environ.get(BIBO_DATABASE_ENV_VAR)
+    database = ctx.parent.params.get("database")
     if database:
         data = load_database(database)
     else:
         data = []
     data = bib_entries(data)
-    return [x["key"] for x in data if incomplete.lower() in x["key"].lower()]
+    return [x["key"] for x in data if x["key"].startswith(incomplete.lower())]
 
 
 def load_database(database):
@@ -187,35 +182,44 @@ def unique_key_validation(new_key, data):
         raise click.ClickException("Duplicate key, command aborted")
 
 
-def complete_path(ctx, args, incomplete):
-    """
-    Autocompletion for files, matches the glob of incomplete argument, and
-    provide basename prompts.
-    """
-    wildc_path = os.path.expanduser(os.path.expandvars(incomplete)) + "*"
-    options = []
-    for path in glob.glob(wildc_path):
-        if os.access(path, os.R_OK):
-            options.append((path, os.path.basename(path)))
-    return options
-
-
 def bold(s: str) -> str:
     """Return `s` wrapped in ANSI bold."""
     return "{}{}{}".format(_ANSI_BOLD, s, _ANSI_UNBOLD)
 
 
-def highlight_text(text, highlight):
+def highlight_text(text: str, highlight: str) -> str:
     """
     Return `text` with sub-string `highlight` in bold.
     """
+    # This is tricky because `text` might contain ANSI escape characters
+    # that shouldn't get highlighted. A state machine to track whether
+    # inside an ANSI sequence, and manual replacement with bold if found
+    # otherwise.
+    chars = list(text)
+    n = len(highlight)
 
-    def highlighter(s):
-        return bold(s.group(0))
+    in_ansi = False
+    skip = 0
+    res = []
+    for i, char in enumerate(chars):
+        if skip > 0:
+            skip -= 1
+            continue
 
-    text = re.sub(highlight, highlighter, text, flags=re.IGNORECASE)
-    # Drop ANSI unbold followed by ANSI bold
-    return text.replace(_ANSI_UNBOLD + _ANSI_BOLD, "")
+        if not in_ansi and char == "\033":
+            in_ansi = True
+
+        candidate = "".join(chars[i : i + n])
+        if not in_ansi and candidate.lower() == highlight.lower():
+            res.append(bold(candidate))
+            skip = n - 1
+        else:
+            res.append(char)
+
+        if in_ansi and char == "m":
+            in_ansi = False
+
+    return "".join(res).replace(_ANSI_UNBOLD + _ANSI_BOLD, "")
 
 
 def highlight_match(
